@@ -1,9 +1,9 @@
-/***************************************************************************
- *                                                                         *
- *   SPDX-FileCopyrightText: 2019 Nicolas Fella <nicolas.fella@gmx.de>                   *
- *                                                                         *
- *   SPDX-License-Identifier: GPL-2.0-or-later
- ***************************************************************************/
+/*
+
+    SPDX-FileCopyrightText: 2019 Nicolas Fella <nicolas.fella@gmx.de>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "modulesmodel.h"
 
@@ -81,7 +81,12 @@ int ModulesModel::rowCount(const QModelIndex &parent) const
 
 QHash<int, QByteArray> ModulesModel::roleNames() const
 {
-    return {{NameRole, "name"}, {DescriptionRole, "description"}, {IconNameRole, "iconName"}, {KcmRole, "kcm"}};
+    return {
+        {NameRole, "name"},
+        {DescriptionRole, "description"},
+        {IconNameRole, "iconName"},
+        {KcmRole, "kcm"},
+    };
 }
 
 KQuickAddons::ConfigModule *ModulesModel::instantiateKcm(const QString &name) const
