@@ -1,9 +1,9 @@
-/***************************************************************************
- *                                                                         *
- *   SPDX-FileCopyrightText: 2019 Nicolas Fella <nicolas.fella@gmx.de>                   *
- *                                                                         *
- *   SPDX-License-Identifier: GPL-2.0-or-later
- ***************************************************************************/
+/*
+
+    SPDX-FileCopyrightText: 2019 Nicolas Fella <nicolas.fella@gmx.de>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #pragma once
 
@@ -28,7 +28,12 @@ class ModulesModel : public QAbstractListModel
     Q_OBJECT
 
 public:
-    enum ModelRoles { NameRole = Qt::DisplayRole, IconNameRole = Qt::DecorationRole, DescriptionRole = Qt::UserRole + 1, KcmRole };
+    enum ModelRoles {
+        NameRole = Qt::DisplayRole,
+        IconNameRole = Qt::DecorationRole,
+        DescriptionRole = Qt::UserRole + 1,
+        KcmRole,
+    };
 
 public:
     ModulesModel(QObject *parent = nullptr);
